#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unlambda
version:              0.1.4.2
visibility:           public
id:                   unlambda-0.1.4.2-EEOcTZHCCPJJQq5u11tP3g
key:                  unlambda-0.1.4.2-EEOcTZHCCPJJQq5u11tP3g
license:              LicenseRef-GPL
maintainer:           Nikolay Amiantov <ab@fmap.me>
author:
    Ørjan Johansen <oerjan@nvg.ntnu.no>
    Don Stewart <http://www.cse.unsw.edu.au/~dons>

stability:            Stable
synopsis:             Unlambda interpreter
description:
    This is an interpreter of the Unlambda language,
    written in the pure, lazy, functional language Haskell.

category:             Compilers/Interpreters
abi:                  12b93f468870d6c60123edd633771c98
exposed:              True
exposed-modules:      Language.Unlambda
import-dirs:          /usr/lib/ghc-8.10.5/site-local/unlambda-0.1.4.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/unlambda-0.1.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/unlambda-0.1.4.2
hs-libraries:         HSunlambda-0.1.4.2-EEOcTZHCCPJJQq5u11tP3g
depends:              array-0.5.4.0 base-4.14.2.0 mtl-2.2.2 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/unlambda/html/unlambda.haddock
haddock-html:         /usr/share/doc/unlambda/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

